import { Icon } from '@iconify/react/dist/iconify.js';
import { useAtomValue, useSetAtom } from 'jotai';
import { FC, useCallback } from 'react';
import { useNavigate } from 'react-router-dom';
import EditableContent from '../../components/EditableContent';
import { CurrentPatternAtom, SelectedPatternIdAtom } from '../../context/Patterns';
import styles from './PatternHeader.module.css';

const PatternHeader: FC = () => {
  const navigate = useNavigate();
  const currentPattern = useAtomValue(CurrentPatternAtom);
  const setActivePattern = useSetAtom(SelectedPatternIdAtom);
  const handleClosePattern = useCallback(() => {
    setActivePattern(null);
    navigate('/library');
  }, []);

  return (
    <div className={styles.pattern_header}>
      <EditableContent
        as="h3"
        placeholder="Pattern Name"
        value={currentPattern?.name ?? null}
        additionalClassName={styles.content}
      />
      <div className="spacer" />
      <button className="tonal" onClick={handleClosePattern}>
        <Icon icon="material-symbols-light:close" />
        Close Edit
      </button>
    </div>
  );
};

export default PatternHeader;
